#include <bits/stdc++.h>

using namespace std;

#define sz(a) (int)(a).size()

typedef long long ll;
typedef long double ld;

const ld eps = 1e-8;
const ld PI = atan2(0, -1);
bool eq(ld x, ld y)
{
    return abs(x - y) < eps;
}

bool Less(ld x, ld y)
{
    return x + eps < y;
}

bool notLess(ld x, ld y)
{
    return x + eps > y;
}

bool Greater(ld x, ld y)
{
    return x > y + eps;
}

bool notGreater(ld x, ld y)
{
    return x < y + eps;
}

ld sqr(ld x)
{
    return x * x;
}

ld Sqrt(ld x)
{
    if (x < -eps)
    {
        cerr << "SQRT OF NEGATIVE NUMBER" << endl;
        exit(0);
    }
    if (x < 0)
        return 0;
    return sqrt(x);
}

struct Point
{
    ld x, y;
    Point():
        x(0),
        y(0) {}

    Point(ld x, ld y):
        x(x),
        y(y) {}

    Point operator+(Point p)
    {
        return Point(p.x + x, p.y + y);
    }

    Point operator-(Point p)
    {
        return Point(x - p.x, y - p.y);
    }

    Point operator-()
    {
        return Point(-x, -y);
    }

    void operator+=(Point p)
    {
        x += p.x;
        y += p.y;
    }

    void operator-=(Point p)
    {
        x -= p.x;
        y -= p.y;
    }

    ld operator*(Point p)
    {
        return x * p.x + y * p.y;
    }

    ld operator^(Point p)
    {
        return x * p.y - y * p.x;
    }

    ll len()
    {
        return Sqrt(sqr(x) + sqr(y));
    }

    Point operator*(ld k)
    {
        return Point(k * x, k * y);
    }

    void operator*=(ld k)
    {
        x *= k;
        y *= k;
    }
};

struct Line
{
    ld a, b, c;
    Line():
        a(1),
        b(1),
        c(0) {}

    Line(ld a, ld b, ld c):
        a(a),
        b(b),
        c(c) {}

    Line(Point p, Point q):
        a(p.y - q.y),
        b(q.x - p.x),
        c(-(p.y - q.y) * p.x - (q.x - p.x) * p.y) {}

    ld operator()(Point p)
    {
        return p.x * a + p.y * b + c;
    }
};

Point cross(Line l, Line k)
{
    ld x = -(k.b * l.c - l.b * k.c) / (k.b * l.a - l.b * k.a);
    ld y = -(k.a * l.c - l.a * k.c) / (k.a * l.b - l.a * k.b);
    return Point(x, y);
}

ld E = (ld)1 / eps;


ll has(ld x)
{
    if (x < 0)
        x = 0;
    x *= E;
    ll f = x;
    return x;
}

unordered_map<ll, int> q;

bool parallel(Line l, Line k)
{
    if (abs(l.b) < eps && abs(k.b) < eps)
        return 1;
    return eq(l.a / l.b, k.a / k.b);
}

int solve()
{
    ios::sync_with_stdio(0);
    int n;
    if (!(cin >> n))
        return 1;
    vector<Point> a(2 * n);
    for (int i = 0; i < 2 * n; i++)
        cin >> a[i].x >> a[i].y;
    int x = 0;
  //  Line l(1, -1, 0);
  //  Line k(1, 1, -5);
   // Point kek = cross(l, k);
    //cout << kek.x << " " << kek.y << endl;
    vector<ld> ang(2 * n, 0);
    for (int y = 1; y < 2 * n; y++)
    {
        int z = 1;
        if (y == 1)
            z = 2;
        for (int t = 1; t < 2 * n; t++)
            if (t != z && t != y)
            {
                Line L = Line(a[x], a[y]);
                Line K = Line(a[z], a[t]);
                Point P = cross(L, K);
                ll x = P.x + eps;
                ll y = P.y + eps;
                //cout << x << " " << y << endl;
                ld xx = x;
                ld yy = y;
                if (!eq(xx, P.x) || !eq(yy, P.y) || abs(x) > 1000000 || abs(y) > 1000000 || parallel(L, K))
                    continue;
                q.clear();
                for (int i = 0; i < 2 * n; i++)
                {
                    Point v = a[i] - P;
                    ld x = atan2(v.y, v.x);
                    if (x < 0)
                        x += PI;
                    if (x > PI - eps)
                        x -= PI;
                    ang[i] = x;
                    q[has(x)]++;
                }
                bool ok = 1;
                for (int i = 0; i < 2 * n; i++)
                {
                    if (eq(a[i].x, P.x) && eq(a[i].y, P.y))
                        ok = false;
                    if (q[has(ang[i])] != 2)
                        ok = false;
                }
                if (ok)
                {
                    cout << "Yes\n";
                    /*vector<int> used(2 * n, 0);
                    for (int i = 0; i < 2 * n; i++)
                        if (!used[i])
                        {
                            for (int j = i + 1; j < 2 * n; j++)
                                if (eq(ang[i], ang[j]))
                                {
                                    used[i] = used[j] = 1;
                                    cout << i + 1 << " " << j + 1 <<
                                }
                        }
                        */
                    cout << x << " " << y << endl;
                    return 0;
                }
            }
    }
    cout << "No\n";
    return 0;
}

//#define KEK
int main()
{
    #ifdef KEK
        freopen("in.txt", "r", stdin);
    #endif
    for (int i = 1;; i++)
    {
        #ifdef KEK
            cerr << "Test #" << i << endl;
        #endif
        if (solve())
            break;
    }
    #ifdef KEK
        cerr << "finished in " << clock() * 1000LL / CLOCKS_PER_SEC;
    #endif
    return 0;
}
