#include <iostream>
#include <vector>
#include <map>


using namespace std;

const long long INF = 1e18;


struct Vector{
    long long x, y;

    Vector operator-(Vector other) {
        return {x - other.x, y - other.y};
    }

    long long dotproduct(Vector other) {
        return x * other.x - y * other.y;
    }

    long long crossporoduct(Vector other) {
        return x * other.y - y * other.x;
    }

    bool operator==(Vector other) {
        return x == other.x && y == other.y;
    }
};

const Vector INFINITY = {INF, INF};

long long gcd(long long a, long long b) {
    a = abs(a);
    b = abs(b);
    while (a && b) {
        if (a > b) {
            a = a % b;
        }
        else {
            b = b % a;
        }
    }
    return a + b;
}

struct Line{
    long long a, b, c;

    Line(Vector s, Vector dir) {
        a = dir.y;
        b = -dir.x;
        c = - a * s.x - b * s.y;
    }

    Vector intersect(Line other) {
        if (!(a * other.b - other.a * b)) {
            return INFINITY;
        }

        //cout << (other.c * b - c * other.b) % (a * other.b - other.a * b) << " " << (other.c * a - other.a * c) / (other.b * a - other.a * b) << endl;
        if (!(a * other.b - other.a * b) || (other.c * b - c * other.b) % (a * other.b - other.a * b) || (other.c * a - other.a * c) % (other.b * a - other.a * b)) {
            return INFINITY;
        }
        long long x = (other.c * b - c * other.b) / (a * other.b - other.a * b);
        long long y = -(other.c * a - other.a * c) / (other.b * a - other.a * b);
        return {x, y};
    }

    pair <long long, long long> angle() {
        long long g = gcd(a, b);
        if (a < 0 || (a == 0 && b < 0)) {
            return {-a / g, -b / g};
        }
        return {a / g, b / g};
    }

    void print() {
        cout << a << " " << b << " " << c << endl;
    }
};

vector <Vector> a;



bool solve(Vector c) {
    map <pair <long long, long long>, int> d;
    bool f = true;
    //cout << c.x << " " << c.y << endl;
    for (auto i : a) {
        if (i == c) {
            return false;
        }
        Line l = Line(c, c - i);
        d[l.angle()]++;
        //cout << l.a << " " << l.b << endl;
    }
    //cout << endl;
    for (auto i : d) {
        f &= (i.second == 2);
    }
    return f;
}

int main()
{
    int n;
    cin >> n;
    n *= 2;
    a.resize(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i].x >> a[i].y;
    }
    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            Line l1 = Line(a[i], a[j] - a[i]);
            for (int k = 0; k < n; k++) {
                if (k == i || k == j) {
                    continue;
                }
                for (int z = k + 1; z < n; z++) {
                    if (z == i || z == j) {
                        continue;
                    }
                    Line l2 = Line(a[k], a[z] - a[k]);
                    Vector moon = l1.intersect(l2);
                    //cout << moon.x << " " << moon.y << endl;
                    if (moon == INFINITY || abs(moon.x) > 1e6 || abs(moon.y) > 1e6) {
                        continue;
                    }
                    if (solve(moon)) {
                        cout << "Yes\n" << moon.x << " " << moon.y;
                        return 0;
                    }
                }
            }
        }
    }
    cout << "No";
    return 0;
}
