#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <map>
#include <string>
#include <set>
#include <algorithm>
#include <cmath>
#include <complex>
using namespace std;

void fourier(vector < complex < double > > &v, long long mn = 2) {
	while (v.size() <= mn || (v.size() & (v.size() - 1)) != 0)
		v.push_back(0);
	long long len = v.size();
	long long k = log2(len);
	vector < long long > d(len);
	for (long long i = 0; i < len; i++)
		d[i] = ((d[i >> 1] >> 1) | ((i & 1) << k - 1));
	for (long long i = 0; i < len; i++)
		if (i < d[i])
			swap(v[i], v[d[i]]);
	for (long long l = 1; l < len; l *= 2) {
		complex < double > wd(cos(acos(-1) / l), sin(acos(-1) / l));
		for (long long i = 0; i < len; i += 2 * l) {
			complex < double > w(1, 0);
			for (long long j = 0; j < l; j++) {
				auto v1 = v[i + j];
				auto v2 = v[i + j + l];
				v[i + j] = v1 + v2 * w;
				v[i + j + l] = v1 - v2 * w;
				w *= wd;
			}
		}
	}
}

long long rnd() {
	return (rand() << 16) | rand();
}

long long rnd(long long l, long long r) {
	return l + rnd() % (r - l + 1);
}

struct node {
	node *l, *r;
	long long x, y;
	long long cnt;

	node() {
		l = r = NULL;
		x = 0;
		y = rnd();
		cnt = 1;
	}
	node(long long data) {
		l = r = NULL;
		x = data;
		y = rnd();
		cnt = 1;
	}
};

long long sz(node *v) {
	return !v ? 0 : v->cnt;
}

node * rec(node *v) {
	if (!v)
		return v;
	v->cnt = sz(v->l) + sz(v->r) + 1;
	return v;
}

node *merge(node *l, node *r) {
	if (!l || !r)
		return !l ? r : l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		return rec(l);
	}
	r->l = merge(l, r->l);
	return rec(r);
}

pair < node*, node* > split(node *v, long long cnt) {
	if (!v)
		return{ NULL, NULL };
	if (sz(v->l) >= cnt) {
		auto p = split(v->l, cnt);
		v->l = p.second;
		return { p.first, rec(v) };
	}
	auto p = split(v->r, cnt - 1 - sz(v->l));
	v->r = p.first;
	return { rec(v), p.second };
}

void print(node *v) {
	if (!v)
		return;
	print(v->l);
	cout << v->x << ' ';
	print(v->r);
}

void println(node *v) {
#ifdef _DEBUG
	print(v);
	cout << endl;
#endif
}

void add(node *&root, long long value) {
	root = merge(root, new node(value));
}

const long long aholen = 1e2;
const long long alp = 26;
long long link[aholen][alp], go[aholen][alp], suf[aholen], suff[aholen], sym[aholen], ter[aholen], par[aholen];
long long root = 0;
long long tp = 0;

long long create() {
	for (long long i = 0; i < alp; i++)
		link[tp][i] = go[tp][i] = -1;
	suf[tp] = -1;
	suff[tp] = -1;
	sym[tp] = -1;
	ter[tp] = 0;
	return tp++;
}

void add(string &s) {
	long long pos = root;
	for (long long i = 0; i < s.size(); i++) {
		long long sm = s[i] - 'a';
		if (link[pos][sm] == -1) {
			long long f = create();
			link[pos][sm] = f;
			sym[f] = sm;
			par[f] = pos;
		}
		pos = link[pos][sm];
	}
	ter[pos]++;
}

long long gsuf(long long v);

long long ggo(long long v, long long s) {
	if (go[v][s] != -1)
		return go[v][s];
	if (link[v][s] != -1)
		return go[v][s] = link[v][s];
	if (v == root)
		return go[v][s] = root;
	return go[v][s] = ggo(gsuf(v), s);
}

long long gsuf(long long v) {
	if (suf[v] != -1)
		return suf[v];
	if (v == root || par[v] == root)
		return suf[v] = root;
	return suf[v] = ggo(gsuf(par[v]), sym[v]);
}

long long gsuff(long long v) {
	if (suff[v] != -1)
		return suff[v];
	if (v == root || par[v] == root)
		return suff[v] = root;
	if (ter[gsuf(v)] != 0)
		return suff[v] = gsuf(v);
	return suff[v] = gsuff(gsuf(v));
}

long long gcd(long long a, long long b) {
	return a == 0 ? b : gcd(b % a, a);
}

struct point {
	long long x, y;
};

istream &operator >> (istream &cin, point &p) {
	cin >> p.x >> p.y;
	return cin;
}

struct vec2 {
	long long x, y;
	vec2(point a, point b) {
		x = b.x - a.x;
		y = b.y - a.y;
	}
	vec2(long long a, long long b) {
		x = a;
		y = b;
	}
	void cut() {
		int g = gcd(abs(x), abs(y));
		if (g != 0) {
			x /= g;
			y /= g;
		} else {
			if (x == 0)
				y = y < 0 ? -1 : 1;
			else
				x = x < 0 ? -1 : 1;
		}
	}
};

point operator + (point a, vec2 b) {
	return {a.x + b.x, a.y + b.y};
}

vec2 operator * (vec2 a, long long d) {
	return {a.x * d, a.y * d};
}

bool operator == (vec2 a, vec2 b) {
	return a.x == b.x && a.y == b.y;
}

bool operator < (vec2 a, vec2 b) {
	if (a.x == b.x)
		return a.y < b.y;
	return a.x < b.x;
}

int main() {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	int x;
	cin >> x;
	vector < point > a(x * 2);
	for (auto &el : a)
		cin >> el;
	x *= 2;

	long long range = 2;

	for (int i = 0; i < x; i++) {
		for (int j = i + 1; j < x; j++) {
			vec2 v(a[i], a[j]);
			v.cut();

			for (long long f = -range; f <= range; f++) {
				map < vec2, int > cnt;
				if (f != 0) {
					point moon = a[i] + v * f;

					bool bad = false;
					for (int k = 0; k < x; k++) {
						if (moon.x == a[k].x && moon.y == a[k].y) {
							bad = true;
							break;
						}
						vec2 now(a[k], moon);
						now.cut();

						vec2 back = now * (-1);
						if (back < now)
							swap(back, now);

						cnt[now]++;
					}
					for (auto el : cnt)
						if (el.second % 2 == 1)
							bad = true;
					if (cnt.size() == 1)
						bad = true;
					if (!bad) {
						cout << "Yes" << endl;
						cout << moon.x << ' ' << moon.y;
						return 0;
					}
				}
			}
		}
	}
	cout << "No";
}