#include <map>
#include <set>
#include <list>
#include <ctime>
#include <deque>
#include <queue>
#include <stack>
#include <tuple>
#include <chrono>
#include <cstdio>
#include <random>
#include <vector>
#include <cassert>
#include <climits>
#include <complex>
#include <cstdlib>
#include <iomanip>
#include <numeric>
#include <iostream>
#include <algorithm>
#include <functional>
#include <unordered_map>
#include <unordered_set>

using namespace std;
using namespace chrono;

mt19937_64 rnd(42);

inline int gcd(int a, int b) {
	return b ? gcd(b, a%b) : a;
}

struct Point {
	int64_t x, y;
};

struct Line {
	int64_t a, b, c;
	
	Line(const Point &p1, const Point &p2)
		: a(p2.y - p1.y), b(p1.x - p2.x), c(-(a * p1.x + b * p1.y)) {
	}
	
	inline void truncate() {
		int64_t g = gcd(a, b);
		if (a < 0 || (a == 0 && b < 0)) {
			a *= -1; b *= -1; c *= -1;
		}
		a /= g; b /= g; c /= g;
	}
	
	inline int64_t relPos(const Point &p) const {
		return a*p.x + b*p.y + c;
	}
};

inline bool operator<(const Point &a, const Point &b) {
	return make_pair(a.x, a.y) < make_pair(b.x, b.y);
}

inline bool operator<(const Line &a, const Line &b) {
	return make_tuple(a.a, a.b, a.c) < make_tuple(b.a, b.b, b.c);
}

inline bool operator==(const Line &a, const Line &b) {
	return make_tuple(a.a, a.b, a.c) == make_tuple(b.a, b.b, b.c);
}

inline bool intersect(const Line &l1, const Line &l2, int64_t &x, int64_t &y) {
	int64_t num1 = l1.c*l2.b - l1.b*l2.c;
	int64_t num2 = l1.a*l2.c - l1.c*l2.a;
	int64_t div  = l1.b*l2.a - l1.a*l2.b;
	if (div == 0 || num1 % div != 0 || num2 % div != 0) {
		return false;
	}
	x = num1 / div;
	y = num2 / div;
	return true;
}

namespace std {
	template<typename A, typename B>
	struct hash< pair<A, B> > {
		hash<A> ha;
		hash<B> hb;
		
		inline size_t operator()(const pair<A, B> &p) const {
			return ha(p.first) ^ hb(p.second);
		}
	};
}

int main() {
	#ifdef DEBUG
	//	freopen("input.txt", "r", stdin);
	#endif
	ios_base::sync_with_stdio(false);
	
	clock_t time = clock();
	const clock_t maxTime = 4.8 * CLOCKS_PER_SEC;
	
	int n; cin >> n; n *= 2;
	vector<Point> pt(n);
	for (int i = 0; i < n; i++) {
		cin >> pt[i].x >> pt[i].y;
	}
	sort(pt.begin(), pt.end());
	
	vector<Line> ln;
	for (int i = 0; i < n; i++) {
		for (int j = 0; j < i; j++) {
			ln.push_back(Line(pt[i], pt[j]));
			ln.back().truncate();
		}
	}
	sort(ln.begin(), ln.end());
	auto lnu = unique(ln.begin(), ln.end());
	ln.erase(lnu, ln.end());
	
	unordered_map< pair<int64_t, int64_t>, int> intr;
	
	while (clock() - time < maxTime && !ln.empty()) {
		int lnId = rnd() % ln.size();
		swap(ln.back(), ln[lnId]);
		Line lKur = ln.back();
		ln.pop_back();
		intr.clear();
		for (const Line &l: ln) {
			int64_t x, y;
			if (
				intersect(lKur, l, x, y) &&
				!binary_search(pt.begin(), pt.end(), Point {x, y}) &&
				abs(x) <= (int64_t)1e6 &&
				abs(y) <= (int64_t)1e6
			) {
				int &val = intr[{x, y}];
				val++;
				if (val == n/2 - 1) {
					cout << "Yes\n";
					cout << x << " " << y << "\n";
					return 0;
				}
			}
		}
	}
	
	cout << "No\n";
	return 0;
}
