#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <cassert>
#include <algorithm>
#include <string>
#include <bitset> 
using namespace std;
#define int long long
#define INF 1791791791

int gcd(int a, int b)
{
	if (b == 0)
		return a;
	return gcd(b, a % b);
}

struct pv
{
	int x, y;
	pv(){}
	pv(int x, int y) : x(x), y(y) {}
	pv(pv a, pv b)
	{
		x = b.x - a.x;
		y = b.y - a.y;
		int g = gcd(abs(x), abs(y));
		if (g) {
			x /= g;
			y /= g;
		}
	}
	int operator%(pv b)
	{
		return x * b.y - y * b.x;
	}
	pv operator*(int k)
	{ 
		return { x * k, y * k };
	}
	pv operator+(pv b)
	{
		return { x + b.x, y + b.y };
	}
	constexpr bool operator<(const pv & b) const
	{
		return x < b.x || x == b.x && y < b.y;
	}
	constexpr bool operator==(const pv & b) const
	{
		return x == b.x && y == b.y;
	}
};

bool intersect(pv av, pv at, pv bv, pv bt, pv & res)
{
	int l = -1e7, r = 1e7;
	bool ls = pv(bt, at + av * l) % bv > 0;
	bool rs = pv(bt, at + av * r) % bv > 0;
	if (ls == rs)
		return false;
	while (r - l > 1) {
		int m = (r + l) / 2;
		bool ms = pv(bt, at + av * m) % bv > 0;
		if (ms == ls)
			l = m;
		else
			r = m;
	}
	if (pv(bt, at + av * l) % bv == 0) {
		res = at + av * l;
		return true;
	}
	if (pv(bt, at + av * r) % bv == 0) {
		res = at + av * r;
		return true;
	}
	return false;
}

struct cmp
{
	bool operator()(pair<pv, pv> a, pair<pv, pv> b) {
		return a.first < b.first || a.first == b.first && !(pv(a.second, b.second) == a.first) && !(pv(a.second, b.second) == a.first * -1) && a.second < b.second;
	}
};

signed main()
{
	cin.tie();
	cout.tie();
	ios::sync_with_stdio(false);
	int n;
	cin >> n;
	vector<pv> a(2 * n);
	set<pv> s;
	for (int i = 0; i < 2 * n; ++i) {
		cin >> a[i].x >> a[i].y;
		s.insert(a[i]);
	}
	map<pair<pv, pv>, int> p;
	for (int i = 0; i < 2 * n; ++i) {
		for (int j = i + 1; j < 2 * n; ++j) {
			++p[{pv(a[i], a[j]), a[i]}];
		}
	}
	map<pv, int> cnt;
	for (auto i = p.begin(); i != p.end(); ++i) {
		if (i->second == 1)
			for (auto j = next(i); j != p.end(); ++j)
				if (j->second == 1) {
					pv r;
					if (intersect(i->first.first, i->first.second, j->first.first, j->first.second, r) && !s.count(r) && abs(r.x) <= 1000000 && abs(r.y) <= 1000000) {
						++cnt[r];
						if (cnt[r] == n * (n - 1) / 2) {
							cout << "Yes\n" << r.x << ' ' << r.y;
							return 0;
						}
					}
				}
	}
	cout << "No\n";
}

