#include <iostream>
#include <vector>
#include <set>
#include <queue>
#include <algorithm>
#include <cassert>

using namespace std;

typedef long long ll;

const ll INF = (ll) 1e18;

struct KG {
    struct Edge {
        ll t, c, f, indRev;
    };

    int n;
    vector<vector<Edge>> g;
    vector<ll> d;
    vector<int> ptr;
    int st, fn;

    ll maxC = 0;
    void add(int v, int t, ll c) {
        int ind = g[v].size();
        int indRev = g[t].size();
        g[v].push_back({t, c, 0, indRev});
        g[t].push_back({v, 0, 0, ind});
        maxC = max(maxC, c);
    }

    void push(Edge &e, ll p) {
        e.f += p;
        g[e.t][e.indRev].f -= p;
    }

    ll h;

    bool bfs() {
        d.assign(n, INF);
        d[st] = 0;
        queue<int> q;
        q.push(st);
        while (!q.empty()) {
            int v = q.front();
            q.pop();
            for (auto &e : g[v]) {
                if (e.f <= e.c - h && d[e.t] > d[v] + 1) {
                    d[e.t] = d[v] + 1;
                    q.push(e.t);
                }
            }
        }
        return d[fn] != INF;
    }

    ll dfs(int v, ll f = INF) {
        if (v == fn) {
            return f;
        }
        for (int &i = ptr[v]; i < g[v].size(); ++i) {
            auto &e = g[v][i];
            if (e.f <= e.c - h && d[e.t] == d[v] + 1) {
                if (ll p = dfs(e.t, min(f, (ll) (e.c - e.f)))) {
                    push(e, p);
                    return p;
                }
            }
        }
        return 0;
    }

    ll dinic() {
        ll flow = 0;
        for (h = maxC; h > 0; h /= 2) {
            while (bfs()) {
                ptr.assign(n, false);
                while (ll p = dfs(st)) {
                    flow += p;
                }
            }
        }
        return flow;
    }

    KG(int n): n(n), g(n), d(n), ptr(n, 0), st(n - 2), fn(n - 1) { }
};

struct Graph {
    int n;
    vector<vector<int>> g;
    vector<ll> sz;
    vector<ll> sumc;
    vector<pair<ll, ll>> mins;
    vector<pair<int, int>> indMins;
    vector<ll> cs;

    void add(int v, int u) {
        g[v].push_back(u);
    }

    void readCs() {
        cs[0] = 0;
        for (int i = 1; i < n; ++i) {
            cin >> cs[i];
        }
    }

    ll dfs(int v) {
        mins[v].first = INF, mins[v].second = INF;
        sz[v] = 1;
        sumc[v] = cs[v];
        ll here = 0;
        set<pair<ll, int>> s;
//        vector<pair<ll, int>> s;
        for (auto to : g[v]) {
            here += dfs(to);
            if (mins[to].first < mins[v].first) {
                mins[v].second = mins[v].first;
                indMins[v].second = indMins[v].first;
                mins[v].first = mins[to].first;
                indMins[v].first = to;
            } else if (mins[to].first < mins[v].second) {
                mins[v].second = mins[to].first;
                indMins[v].second = to;
            }
            sz[v] += sz[to];
            sumc[v] += sumc[to];
//            s.push_back({sz[to], to});
            s.insert({sz[to], to});
            here += sumc[to];
        }
//        sort(s.rbegin(), s.rend());
//        ll res = 0;
        ll res = !g[v].empty() * INF;
//        for (int i = 0; i < s.size(); ++i) {
//            for (int j = i + 1; s[i].first && j < s.size(); ++j) {
//                ll db = min(s[i].first, s[j].first);
//                s[i].first -= db;
//                s[j].first -= db;
//            }
//            res += s[i].first * mins[v].first;
//        }
//        KG h(2 * g[v].size() + 2);
//        for (int i = 0; i < g[v].size(); ++i) {
//            h.add(h.st, i, sz[g[v][i]]);
//            for (int j = 0; j < g[v].size(); ++j) {
//                if (i == j) continue;
//                h.add(i, g[v].size() + j, INF);
//            }
//            h.add(g[v].size() + i, h.fn, sz[v]);
//        }
//        ll res = (sz[v] - 1 - h.dinic()) * mins[v].first;
        while (s.size() > 1) {
            auto p = *s.rbegin();
            s.erase(--s.end());
            auto pp = *s.rbegin();
            s.erase(--s.end());
            p.first -= pp.first;
            if (p.first) {
                s.insert(p);
            }
        }
        if (!s.empty()) {
            auto p = *s.begin();
//            if (p.second != indMins[v].first) {
//                res = min(res, p.first * mins[v].first);
//            } else {
                res = min(res, p.first * mins[v].second);
//            }
            if (sz[indMins[v].first] <= sz[v] / 2) {
                res = min(res, p.first * mins[v].first);
            }
        } else {
            res = 0;
        }
        if (!g[v].empty()) {
            if (sz[indMins[v].first] > sz[v] / 2) {
                res = min(res, (sz[indMins[v].first] - (sz[v] - 1 - sz[indMins[v].first])) * mins[v].second);
            }
        }
        here += res;
        if (cs[v] < mins[v].first) {
            mins[v].first = cs[v];
        } else if (cs[v] < mins[v].second) {
            mins[v].second = cs[v];
        }
        return here;
    }

    Graph(int n) :
            n(n), g(n), sz(n), sumc(n),
            mins(n), indMins(n), cs(n) {}
};

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(NULL);
    int n;
    cin >> n;
    Graph g(n);
    for (int i = 1, p; i < n; ++i) {
        cin >> p;
        g.add(--p, i);
    }
    g.readCs();
    cout << g.dfs(0) << "\n";
    return 0;
}
/*
5
1 2 2 1
1 1 1 1

6
1 1 1 4 4
1 2 3 4 5

8
1 1 1 3 3 4 4
1 1000 1000 1000 1000 1000 1000
 */






//        ll secondVar = INF;
//        if (!g[v].empty()) {
//            auto ost = sz[indMins[v].first];
//            sr.erase({sz[indMins[v].first], indMins[v].first});
//            while (ost && !sr.empty()) {
//                auto p = *sr.rbegin();
//                sr.erase(--sr.end());
//                ll db = min(ost, p.first);
//                p.first -= db;
//                ost -= db;
//                if (p.first) {
//                    sr.insert(p);
//                }
//            }
//            if (!sr.empty()) {
//                while (sr.size() > 1) {
//                    auto p = *sr.rbegin();
//                    sr.erase(--sr.end());
//                    auto pp = *sr.rbegin();
//                    sr.erase(--sr.end());
//                    p.first -= pp.first;
//                    if (p.first) {
//                        sr.insert(p);
//                    }
//                }
//                if (!sr.empty()) {
//                    auto p = *sr.begin();
//                    res = min(res, p.first * mins[v].first);
//                } else {
//                    res = 0;
//                }
//            } else {
//                res = min(res, ost * mins[v].second);
//            }
//        }
//        here += min(firstVar, secondVar);
//        for (auto to : g[v]) {
//            auto sr = s;
//            sr.erase({sz[to], to});
//            while (sr.size() > 1) {
//                auto p = *sr.rbegin();
//                sr.erase(--sr.end());
//                auto pp = *sr.rbegin();
//                sr.erase(--sr.end());
//                p.first -= pp.first;
//                if (p.first) {
//                    sr.insert(p);
//                }
//            }
//            ll num = sz[to];
//            if (!sr.empty()) {
//                auto p = *sr.begin();
//                if (p.first > sz[to]) continue;
//                num -= p.first;
//            }
//            if (indMins[v].first == to) {
//                res = min(res, num * mins[v].second);
//            } else {
//                res = min(res, num * mins[v].first);
//            }
//        }