#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

const double PI = acos(-1);
const double EPS = 1e-9;

double mySqrt(double a) {
    if (a < 0) {
        return 0;
    }
    return sqrt(a);
}

double sqr(double a) {
    return a * a;
}

bool doubleEqual(const double &a, const double &b) {
    return fabs(a - b) < EPS;
}

struct Point {
    double x, y;
    Point(): x(0), y(0) {}

    Point(double x, double y): x(x), y(y) { }

    Point operator+(const Point &p) const {
        return Point(x + p.x, y + p.y);
    }

    Point operator-(const Point &p) const {
        return Point (x - p.x, y - p.y);
    }

    Point operator-() const {
        return Point(-x, -y);
    }

    double operator%(const Point &p) const {
        return x * p.x + y * p.y;
    }

    double operator*(const Point &p) const {
        return x * p.y - y * p.x;
    }

    Point operator*(const double &k) const {
        return Point(x* k, y * k);
    }

    double length() const {
        return mySqrt(*this % *this);
    }

    double distTo(const Point &p) const {
        return (*this - p).length();
    }

    Point rotate() const {
        return Point (-y, x);
    }

    Point rotate(double alpha) const {
        Point v;
        Point a = *this;
        v.x = a.x * cos(alpha) - a.y * sin(alpha);
        v.y = a.x * sin(alpha) + a.y * cos(alpha);
        return v;
    }
};

bool isGood(double k) {
    return ceil(k) == floor(k);
}

double getK(const Point&A, const Point &B) {
    Point v = B - A;
    return v.y / v.x;
}

int intersection(const Point &A, const Point &B, const Point &C, const Point &D, Point &O) {
    Point v = B - A, u = (D - C);
    double k1 = v.y / v.x, k2 = u.y / u.x;
    if (v.x == 0 && u.x == 0) {
        return 0;
    }
    if (v.x == 0) {
        double b2 = C.y - k2 * C.x;
        O.x = A.x;
        O.y = k2 * O.x + b2;
        return isGood(O.x) && isGood(O.y);
    }
    if (u.x == 0) {
        double b1 = A.y - k1 * A.x;
        O.x = C.x;
        O.y = k1 * O.x + b1;
        return isGood(O.x) && isGood(O.y);
    }
    if (k1 == k2) {
        return 0;
    }
    double b1 = A.y - k1 * A.x;
    double b2 = C.y - k2 * C.x;
    O.x = (b2 - b1) / (k1 - k2);
    O.y = k1 * O.x + b1;
    return isGood(O.x) && isGood(O.y);
}

istream &operator>>(istream &in, Point &p) {
    in >> p.x >> p.y;
    return in;
}

map<pair<int, int>, bool> exist;

void solve(vector<Point> &pts) {
    int n = pts.size();
    Point A = pts[0];
    for (int i = 2; i < n; ++i) {
        Point B = pts[i];
        Point C = pts[1];
        for (int j = 2; j < n; ++j) {
            if (j == i) {
                continue;
            }
            Point D = pts[j];
            Point O;
            int k = intersection(A, B, C, D, O);
            if (exist[{O.x, O.y}]) {
                continue;
            }
            if (!k) {
                continue;
            }
            map<double, int> data;
            for (int l = 2; l < n; ++l) {
                if (l == i || l == j) {
                    continue;
                }
                data[getK(pts[l], O)]++;
            }
            bool fl = 0;
            for (auto x: data) {
                if (x.second != 2) {
                    fl = 1;
                    break;
                }
            }
            if (!fl) {
                cout << "Yes\n";
                if (O.x == 0) {
                    O.x = abs(O.x);
                }
                if (O.y == 0) {
                    O.y = abs(O.y);
                }
                cout << fixed << setprecision(0) << O.x << " " << O.y << "\n";
                exit(0);
            }
        }
    }
}

int main() {
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    vector<Point> pts(2 * n);
    for (auto &p: pts) {
        int a, b;
        cin >> a >> b;
        exist[{a, b}] = 1;
        p = Point(a, b);
    }
    solve(pts);
    swap(pts[1], pts[2]);
    solve(pts);
    cout << "No\n";
}