#include<iostream>
#include<vector>
#include<algorithm>
#include<string>
#include<set>
#include<climits>
#include<map>

using namespace std;

struct point
{
	long long x, y;
	point(long long a, long long b)
	{
		x = a, y = b;
	}
	point(point a, point b)
	{
		x = a.x - b.x;
		y = a.y - b.y;
	}
	point()
	{
		x = y = 0;
	}
	bool operator== (point a)
	{
		return x == a.x && y == a.y;
	}
};

struct line
{
	long long a, b, c;
	line(point x, point y)
	{
		point xy(x, y);
		swap(xy.x, xy.y);
		xy.x = -xy.x;
		a = xy.x, b = xy.y;
		c = -a * x.x - b * x.y;
	}
};

long long gcd(long long a, long long b)
{
	while (b != 0)
	{
		long long tmp = b;
		b = a % b;
		a = tmp;
	}
	return a;
}

bool intersect_lines(line ab, line cd, point &inter)
{
	long long firstx = (long long)cd.c * ab.b - (long long)ab.c * cd.b;
	long long secondx = (long long)cd.b * ab.a - (long long)ab.b * cd.a;
	if (secondx == 0 || firstx % secondx != 0)
		return false;
	long long firsty = (long long)cd.c * ab.a - (long long)ab.c * cd.a;
	long long secondy = cd.a * ab.b - ab.a * cd.b;
	if (secondy == 0 || firsty % secondy != 0)
		return false;
	inter.x = firstx / secondx, inter.y = firsty / secondy;
	return true;
}

void normalize(line &a)
{
	long long g = gcd((abs(a.a), abs(a.b)), a.c);
	a.a /= g;
	a.b /= g;
	a.c /= g;
	if (a.a < 0)
		a.a = -a.a, a.b = -a.b, a.c = -a.c;
	else if (a.a == 0)
	{
		if (a.b < 0)
			a.b = -a.b, a.c = -a.c;
		else if (a.b == 0)
		{
			if (a.c < 0)
				a.c = -a.c;
		}
	}
}

int main()
{
	int n;
	cin >> n;
	vector<point> a(2 * n);
	for (int i = 0; i < 2 * n; ++i)
		cin >> a[i].x >> a[i].y;
	for (int i = 1; i < a.size(); ++i)
	{
		line ab(a[0], a[i]);
		int j;
		if (i == 1)
			j = 2;
		else
			j = 1;
		for (int k = 1; k < a.size(); ++k)
		{
			if (k == i)
				continue;
			line cd(a[j], a[k]);
			point inter(0, 0);
			if (intersect_lines(ab, cd, inter))
			{
				map<pair<pair<long long, long long>, long long>, int> lines;
				int b;
				for (b = 0; b < a.size(); ++b)
				{
					if (a[b] == inter)
						break;
					line moonriver(a[b], inter);
					normalize(moonriver);
					if (lines[{ {moonriver.a, moonriver.b}, moonriver.c }] < 2)
						++lines[{ {moonriver.a, moonriver.b}, moonriver.c }];
					else
						break;
				}
				if (b >= a.size())
				{
					cout << "Yes\n";
					cout << inter.x << " " << inter.y;
					//system("pause");
					return 0;
				}
			}
		}
	}
	cout << "No";
	//system("pause");
	return 0;
}