#include <bits/stdc++.h>
#define ll long long

using namespace std;

const int INF = 1e9 + 7;
const int MAXN = 1e6;
const double EPS = 1e-6;

struct TVector {
   double x, y;
};

TVector operator+(TVector a, TVector b) {
    return {a.x + b.x, a.y + b.y};
}

TVector operator-(TVector a, TVector b) {
    return {a.x - b.x, a.y - b.y};
}

double operator*(TVector a, TVector b) {
    return a.x * b.y - a.y * b.x;
}

double operator%(TVector a, TVector b) {
    return a.x * b.x + a.y * b.y;
}

double len(TVector a) {
    return sqrt(a % a);
}

TVector norm(TVector a) {
    return {a.x / len(a), a.y / len(a)};
}

TVector operator*(TVector a, double k) {
    return {a.x * k, a.y * k};
}

struct TLine {
    double a, b, c;
    TLine(TVector A, TVector B) {
        a = A.y - B.y;
        b = B.x - A.x;
        c = A.y * B.x - A.x * B.y;
    }
};

TLine norm(TLine l1) {
    if (abs(l1.a) < EPS) {
        l1.c /= l1.b;
        l1.b /= l1.b;
        return l1;
    }
    l1.c /= l1.a;
    l1.b /= l1.a;
    l1.a /= l1.a;
    return l1;
}

bool operator==(TVector a, TVector b) {
    return abs(a.x - b.x) < EPS && abs(a.y - b.y) < EPS;
}

bool operator==(TLine l1, TLine l2) {
    l1 = norm(l1);
    l2 = norm(l2);
    return abs(l1.a - l2.a) < EPS && abs(l1.b - l2.b) < EPS && abs(l1.c - l2.c) < EPS;
}

bool parallel(TLine l1, TLine l2) {
    l1 = norm(l1);
    l2 = norm(l2);
    return abs(l1.a - l2.a) < EPS && abs(l1.b - l2.b) < EPS;
}

TVector intersection(TLine l1, TLine l2) {
    if (l1 == l2 || parallel(l1, l2)) {
        assert(false);
    }
    l1 = norm(l1);
    l2 = norm(l2);
    if (abs(l2.a) < EPS) {
        swap(l1, l2);
    }
    TVector A;
    if (abs(l1.a) < EPS) {
        A.y = l1.c / l1.b;
        A.x = l2.c - l2.b * A.y;
        return A;
    }
    A.y = (l1.c - l2.c) / (l1.b - l2.b);
    A.x = l1.c - l1.b * A.y;
    return A;

}

int main() {
    #ifdef MY
        freopen("input.txt", "r", stdin);
    #else
        ios_base::sync_with_stdio(false);
        cin.tie(0);
        cout.tie(0);
    #endif // MY
    int n;
    cin >> n;
    n *= 2;
    vector <TVector> a(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i].x >> a[i].y;
    }
    if (n == 2) {
        TLine l(a[0], a[1]);
        for (int x = -MAXN; x <= MAXN; x++) {
            double y = (l.c - l.a * x) / l.b;
            if (abs(round(y) - y) > EPS) continue;
            if (abs(y) > MAXN + EPS) continue;
            cout << "Yes\n";
            cout << (int) round(x) << " " << (int) round(y) << "\n";
            return 0;
        }
        cout << "No\n";
        return 0;
    }
    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            if (i == j) continue;
            TLine l1(a[i], a[j]);
            for (int i1 = 0; i1 < n; i1++) {
                if (i1 == i || i1 == j) continue;
                for (int j1 = i1 + 1; j1 < n; j1++) {
                    if (i1 == j1 || i == j1 || j == j1) continue;
                    TLine l2(a[i1], a[j1]);
                    if (parallel(l1, l2) || l1 == l2) continue;
                    TVector O = intersection(l1, l2);
                    bool can = true;
                    for (int k = 0; k < n; k++) {
                        if (O == a[k]) {
                            can = false;
                            break;
                        }
                    }
                    if (abs(round(O.x) - O.x) > EPS) continue;
                    if (abs(round(O.y) - O.y) > EPS) continue;
                    if (abs(O.x) > MAXN) continue;
                    if (abs(O.y) > MAXN) continue;
                    for (int k = 0; k < n; k++) {
                        if (k == i || k == j || k == i1 || k == j1) continue;
                        int pr = -1;
                        for (int l = k + 1; l < n; l++) {
                            if (l == k || l == j || l == i || l == i1 || l == j1) continue;
                            TLine l3(a[k], a[l]);
                            if (l1 == l3 || l2 == l3) continue;
                            if (abs(l3.a * O.x + l3.b * O.y - l3.c) < EPS) {
                                if (pr != -1) {
                                    can = false;
                                } else {
                                    pr = l;
                                }
                            }
                        }
                    }
                    if (can) {
                        cout << "Yes\n";
                        //cout << i << " " << j << " " << i1 << " " << j1 << "\n";
                        l1 = norm(l1);
                        l2 = norm(l2);
//                        cout << l1.a << " " << l1.b << " " << l1.c << "\n";
//                        cout << l2.a << " " << l2.b << " " << l2.c << "\n";
                        cout << (int) round(O.x) << " " << (int) round(O.y) << "\n";
                        return 0;
                    }
                }
            }
        }
    }
    cout << "No\n";
}
