#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <cmath>
#include <string>
#include <time.h>
#include <random>
#include <algorithm>

using namespace std;
mt19937 rnd(time(NULL));

struct Point {
    bool bad;
    int x, y;
};

struct Line {
    Point st;
    int dx, dy;
};

int gcd(int a, int b) {
    while (b) {
        int tmp = a % b;
        a = b;
        b = tmp;
    }
    return a;
}

Point init(int x, int y) {
    Point res;
    res.x = x;
    res.y = y;
    return res;
}

Line getln(Point a, Point b) {
    int dx = a.x - b.x;
    int dy = a.y - b.y;
    int d = gcd(dx, dy);

    Line l;
    l.st = a;

    l.dx = dx / d;
    l.dy = dy / d;

    if (l.dx < 0) {
        l.dx *= -1;
        l.dy *= -1;
    }

    return l;
}

int getrand(int n, int curr, vector <bool> &used) {
    while (true) {
        int p = rnd() % n;
        if (!used[p] && p != curr) return p;
    }
}

pair <int, int> mgcd(int a, int b) {
    if (b == 0) return { 1, 0 };
    if (a == 0) return { 0, 1 };

    int d = a / b;
    pair <int, int> tmp = mgcd(b, a % b);
    return { tmp.second, tmp.first - d * tmp.second };
}

Point per(Line a, Line b) {
    Point t;
    if (a.dx == b.dx && a.dy == b.dy) {
        t.bad = true;
        return t;
    }

    int cx = gcd(a.dx, b.dx);
    int rx = a.st.x - b.st.x;

    if (rx % cx) {
        t.bad = true;
        return t;
    }

    int cy = gcd(a.dy, b.dy);
    int ry = a.st.x - b.st.y;

    if (ry % cy) {
        t.bad = true;
        return t;
    }

    pair <int, int> pk = mgcd(a.dx, b.dx);
    int k1 = pk.first * (rx / cx);

    t.bad = false;
    t.x = a.st.x + a.dx * k1;
    t.y = a.st.y + a.dy * k1;

    return t;
}

void solve(vector <Point> a) {
    int n = a.size();
    
    for (int it = 0; it < 1e5; ++it) {
        vector <bool> used(n);
        vector <Line> lines;
        for (int i = 0; i < n; ++i) {
            if (!used[i]) {
                int p = getrand(n, i, used);
                used[i] = true;
                used[p] = true;
                lines.push_back(getln(a[i], a[p]));
            }
        }

        bool check = true;
        set <pair <int, int>> ms;
        for (int i = 0; i < lines.size(); ++i) {
            for (int j = i + 1; j < lines.size(); ++j) {
                Point pt = per(lines[i], lines[j]);
                if (pt.bad) check = false;
                ms.insert({ pt.x, pt.y });
            }
        }

        if (check && ms.size() == 1) {
            cout << "Yes\n";
            pair <int, int> ans = *ms.begin();
            cout << ans.first << ' ' << ans.second << '\n';
            exit(0);
        }
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    freopen("input.txt", "r", stdin);
    

    int n;
    cin >> n;
    n *= 2;

    vector <Point> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i].x >> a[i].y;
    }

    solve(a);

    cout << "No\n";
    return 0;
}