#include <iostream>
#include <vector>
#include <algorithm>


using namespace std;


using lint = long long int;


lint gcd(lint a, lint b) {
    a = abs(a);
    b = abs(b);

    lint temp;

    while (b) {
        temp = a;
        a = b;
        b = temp % b;
    }

    return a;
}


class Q {
    lint p, q;

    void reduce() {
        lint d = gcd(p, q);
        p /= d;
        q /= d;
    }

public:
    Q(lint _p, lint _q = 1) : p(_p), q(_q) {
        reduce();
    }

    Q operator+(const Q &n) const {
        return Q(p * n.q + q * n.p, q * n.q);
    }

    Q operator-(const Q &n) const {
        return Q(p * n.q - q * n.p, q * n.q);
    }

    Q operator*(const Q &n) const {
        return Q(p * n.p, q * n.q);
    }

    Q operator/(const Q &n) const {
        return Q(p * n.q, q * n.p);
    }

    Q operator+(lint n) const {
        return operator+(Q(n));
    }

    Q operator-(lint n) const {
        return operator-(Q(n));
    }

    Q operator*(lint n) const {
        return operator*(Q(n));
    }

    Q operator/(lint n) const {
        return operator/(Q(n));
    }

    Q operator-() const {
        return Q(-p, q);
    }

    Q operator==(const Q &n) const {
        return p == n.p && q == n.q;
    }

    bool integer() const {
        return q == 1;
    }

    operator lint() {
        return p / q;
    }
};


struct Point {
    lint x, y;

    Point() : x(0), y(0) {};
    Point(lint _x, lint _y) : x(_x), y(_y) {};

    bool operator==(const Point &p) const {
        return x == p.x && y == p.y;
    }
};

istream& operator>>(istream &in, Point &p) {
    return in >> p.x >> p.y;
}

ostream& operator<<(ostream &out, const Point &p) {
    return out << p.x << ' ' << p.y;
}


struct Line {
    Point a, b;

    Line() {};
    Line(const Point &_a, const Point &_b) : a(_a), b(_b) {};
};


bool on_line(const Line &n, const Point &p) {
    lint dx = n.a.x - n.b.x, dy = n.a.y - n.b.y;
    lint px = n.a.x - p.x, py = n.a.y - p.y;

    return dx * py == px * dy;
}


bool do_cross(const Line &n, const Line &m) {
    lint nx = n.a.x - n.b.x, ny = n.a.y - n.b.y;
    lint mx = m.a.x - m.b.x, my = m.a.y - m.b.y;

    return nx * my != mx * ny;
}


Point cross_point(Line n, Line m, bool &success) {
    if (!do_cross(n, m)) {
        success = false;

        return Point();
    }

    lint nx = n.a.x - n.b.x, ny = n.a.y - n.b.y;
    lint mx = m.a.x - m.b.x, my = m.a.y - m.b.y;

    if (nx == 0 || mx == 0) {
        if (mx == 0) {
            swap(nx, mx);
            swap(ny, my);
            swap(n, m);
        }

        Q mk(my, mx);
        Q mb(-mk * m.a.x + m.a.y);

        Q py = mk * n.a.x + mb;

        if (!py.integer()) {
            success = false;

            return Point();
        }

        success = true;

        return Point(n.a.x, py);
    }

    Q nk(ny, nx);
    Q nb(-nk * n.a.x + n.a.y);

    Q mk(my, mx);
    Q mb(-mk * m.a.x + m.a.y);

    Q x = (mb - nb) / (nk - mk);
    Q y = nk * x + nb;

    if (!x.integer() || !y.integer()) {
        success = false;

        return Point();
    }

    success = true;
    return Point(x, y);
}


const lint INF = (lint)1e6;


int main() {
    int n;
    cin >> n;

    n *= 2;

    vector<Point> stars(n);
    for (int i = 0; i < n; ++i) {
        cin >> stars[i];
    }

    vector<int> perebor(n, 0);
    perebor[n - 1] = perebor[n - 2] = 2;
    perebor[n - 3] = perebor[n - 4] = 1;

    vector<int> used(n);
    for (int i = 0; i < n - 1; ++i) {
        for (int j = i + 1; j < n; ++j) {
            used.assign(n, 0);
            used[i] = used[j] = true;

            for (int k = 0; k < n - 1; ++k) {
                for (int c = k + 1; c < n; ++c) {
                    if (used[k] || used[c]) {
                        continue;
                    }

                    vector<int> cused = used;
                    cused[k] = cused[c] = true;

                    Line l1(stars[i], stars[j]), l2(stars[k], stars[c]);

                    bool s;
                    Point p = cross_point(l1, l2, s);

                    if (!s) {
                        continue;
                    }

                    for (int cur = 0; cur < n; ++cur) {
                        if (p == stars[cur] || !cused[cur] && (on_line(l1, stars[cur]) || on_line(l2, stars[cur]))) {
                            s = false;
                            break;
                        }
                    }

                    if (!s) {
                        continue;
                    }

                    for (int cur = 0; cur < n; ++cur) {
                        if (cused[cur]) {
                            continue;
                        }

                        cused[cur] = true;

                        Line cl(p, stars[cur]);

                        int cross_cnt = 0;
                        for (int tcur = cur + 1; tcur < n; ++tcur) {
                            if (on_line(cl, stars[tcur])) {
                                cused[tcur] = true;
                                ++cross_cnt;

                                if (cross_cnt > 1) {
                                    break;
                                }
                            }
                        }

                        if (cross_cnt != 1) {
                            s = false;
                            break;
                        }
                    }

                    if (!s) {
                        continue;
                    }

                    if (abs(p.x) > INF || abs(p.y) > INF) {
                        continue;
                    }

                    cout << "Yes" << '\n' << p;

                    return 0;
                }
            }
        }
    }

    cout << "No";

    return 0;
}