#include <iostream>
#include <algorithm>
#include <vector>
#include <fstream>

using namespace std;

inline int gcd(int x, int y)
{
    while (y)
    {
        swap(x, y);
        y %= x;
    }
    return x;
}

const int broken = 1e6 + 5;
const int lim = 1e6;

struct Vector
{
    int x, y;
    explicit Vector(int x = 0, int y = 0) : x(x), y(y) {};
    inline Vector operator -()
    {
        return Vector(-x, -y);
    }
    inline Vector normalize()
    {
        if (!(x || y))
            return Vector(0, 0);
        int d = gcd(abs(x), abs(y));
        if (x > 0 || (x == 0 && y > 0))
            return Vector(x / d, y / d);
        return Vector(-x / d, -y / d);
    }
    inline bool good() const
    {
        return abs(x) <= lim && abs(y) <= lim;
    }
    inline operator bool() const
    {
        return x || y;
    }
};

inline Vector operator +(const Vector &A, const Vector &B)
{
    return Vector(A.x + B.x, A.y + B.y);
}

inline Vector operator -(const Vector &A, const Vector &B)
{
    return Vector(A.x - B.x, A.y - B.y);
}

inline bool operator < (const Vector&A, const Vector&B)
{
    return A.x == B.x ? A.y < B.y : A.x < B.x;
}

inline bool operator == (const Vector&A, const Vector&B)
{
    return A.x == B.x && A.y == B.y;
}

inline bool operator != (const Vector&A, const Vector&B)
{
    return A.x != B.x || A.y != B.y;
}

struct line
{
    long long a, b, c;
    explicit line(int a = 0, int b = 0, int c = 0) : a(a), b(b), c(c) {};
    explicit line(const Vector &A, const Vector &B)
    {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -a * A.x - b * A.y;
    }
    inline int operator()(int x) const
    {
        long long val = - a * x - c;
        if (val % b)
            return broken;
        int ret =  val / b;
        if (ret > lim)
            return broken;
        return ret;
    }
};

inline Vector cross(const line &f, const line &g)
{
    long long A = f.a * g.b - f.b * g.a;
    if (!A)
        return Vector(broken);
    long long C = g.c * f.b - f.c * g.b;
    if (C % A)
        return Vector(broken);
    long long x = C / A;
    if (abs(x) > lim)
        return Vector(broken);
    if (f.b)
        return Vector(x, f(x));
    else
        return Vector(x, g(x));
}

int main()
{
    ifstream cin("input.txt");
    int n;
    cin >> n;
    n *= 2;
    vector<Vector> arr(n);
	sort(arr.begin(), arr.end());
    for (int i = 0; i < n; i++)
        cin >> arr[i].x >> arr[i].y;
    int a = rand() % n;
	int b = rand() % n;
    for (int i = 0; i < n; i++) if (i != a)
    {
        line l(arr[a], arr[i]);
        for (; b == a || b == i; b = rand() % n);
        for (int j = 0; j < n; j++) if (j != a && j != b && j != i)
        {
            line k(arr[b], arr[j]);
            Vector O = cross(l, k);
            if (!O.good())
                continue;
            bool f = 1;
            vector<Vector> arr2(n);
            for (int i = 0; i < n; i++)
                arr2[i] = (arr[i] - O).normalize();
            sort(arr2.begin(), arr2.end());
            for (int i = 0; i < n; i += 2)
            {
                if (!arr2[i])
                {
                    f = 0;
                    break;
                }
                if (i && arr2[i] == arr2[i - 1])
                {
                    f = 0;
                    break;
                }
                if (arr2[i] != arr2[i + 1])
                {
                    f = 0;
                    break;
                }
            }
            if (f)
            {
                cout << "Yes\n" << O.x << " " << O.y;
                return 0;
            }
        }
    }
    cout << "No";
    return 0;
}
