#include <random>
#include <algorithm>
#include <iterator>
#include <iostream>
#include <vector>

using namespace std;

const long long INF = 1e8, MAXN = 5671, MONE = -1, TWO = 2;

long long gcd(long long a, long long b) {
    long long c;
    while (b > 0) {
        c = a % b;
        a = b;
        b = c;
    }
    return a;
}

struct Point {
    long long x, y;

    Point() {}

    Point(long long x1, long long y1) : x(x1), y(y1) {}
};

struct Line {
    long long a, b, c;

    Line() {}

    Line(long long x, long long y, long long z) : a(x), b(y), c(z) {}

    Line(Point x, Point y) : a(y.y - x.y), b(x.x - y.x), c(-a * x.x - b * x.y) {
        long long d = gcd(abs(a), gcd(abs(b), abs(c)));
        if (d > 0) {
            a = a / d;
            b = b / d;
            c = c / d;
            if (a < 0) {
                a = a / MONE;
                b = b / MONE;
                c = c / MONE;
            }
        }
    }
};

struct Seg {
    Point a, b;

    Seg() {}

    Seg(Point x, Point y) : a(x), b(y) {}
};

Point lineint(Line x, Line y) {
    long long px = y.c * x.b - x.c * y.b;
    long long qx = x.a * y.b - y.a * x.b;
    long long py = y.c * x.a - x.c * y.a;
    long long qy = x.b * y.a - y.b * x.a;
    if ((qy == 0) || (qx == 0) || (px % qx != 0) || (py % qy != 0)) {
        return Point(INF, INF);
    } else {
        return Point(px / qx, py / qy);
    }
}

bool Pointinseg(Seg x, Point y) {
    if (((y.x >= x.a.x) && (y.x <= x.b.x)) || ((y.x >= x.b.x) && (y.x <= x.a.x))) {
        return true;
    } else {
        return false;
    }
}

Point segint(Seg x, Seg y) {
    Line lx = Line(x.a, x.b);
    Line ly = Line(y.a, y.b);
    Point li = lineint(lx, ly);
    if (Pointinseg(x, li) && Pointinseg(y, li)) {
        return li;
    } else {
        return Point(INF, INF);
    }
}

Point mirror(Point x, Point y) {
    Point w = Point(TWO * (y.x - x.x), TWO * (y.y - x.y));
    Point z = Point(x.x + w.x, x.y + w.y);
    return z;
}

void debuglineint() {
    long long x1, x2, y1, y2, x3, y3, x4, y4;
    cin >> x1 >> x2 >> y1 >> y2 >> x3 >> y3 >> x4 >> y4;
    Point tmp = lineint(Line(Point(x1, x2), Point(y1, y2)), Line(Point(x3, y3), Point(x4, y4)));
    cout << tmp.x << ' ' << tmp.y;
}

void debugsegint() {
    long long x1, x2, y1, y2, x3, y3, x4, y4;
    cin >> x1 >> x2 >> y1 >> y2 >> x3 >> y3 >> x4 >> y4;
    Point tmp = segint(Seg(Point(x1, x2), Point(y1, y2)), Seg(Point(x3, y3), Point(x4, y4)));
    cout << tmp.x << ' ' << tmp.y;
}

void debugmirror() {
    long long x1, x2, y1, y2;
    cin >> x1 >> y1 >> x2 >> y2;
    Point tmp = mirror(Point(x1, y1), Point(x2, y2));
    cout << tmp.x << ' ' << tmp.y;
}

bool eqp(Point x, Point y) {
    return (x.x == y.x) && (x.y == y.y);
}

bool eql(Line x, Line y) {
    return ((x.a == y.a) && (x.b == y.b) && (x.c == y.c));
}

bool cmpp(Point x, Point y) {
    if (x.x == y.x) {
        return x.y < y.y;
    } else {
        return x.x < y.x;
    }
}

bool cmpl(Line x, Line y) {
    if (x.a == y.a) {
        if (x.b == y.b) {
            return x.c < y.c;
        } else {
            return x.b < y.b;
        }
    } else {
        return x.a < y.a;
    }
}

long long n;


vector<Point> stars;
Line ml[MAXN];

bool fs = 0;



bool check(Point cent){
    if (cent.x < INF){
        for (int i = 0; i < 4; i++){
            if (eqp(cent, stars[i])){
                return false;
            }
        }
        return true;
    }else{
        return false;
    }
}

void solve() {
    random_device myrad;
    mt19937 kek(myrad());
    shuffle(stars.begin(), stars.end(), kek);
    for (long long i = 2; i < n; i++) {
        if (fs) {
            break;
        }
        for (long long j = 2; j < n; j++) {
            if (j == i) {
                continue;
            }
            Point tmp = lineint(Line(stars[0], stars[i]), Line(stars[1], stars[j]));
            if (check(tmp)) {
                cout << "Yes" << endl << tmp.x << ' ' << tmp.y;
                fs = 1;
                break;
            }
        }
    }
}

void sol() {
    cin >> n;
    n = n * 2;
    stars.resize(n);
    for (long long i = 0; i < n; i++) {
        cin >> stars[i].x >> stars[i].y;
    }
    //cout << check(Point(2, 2));
    Point tmp;
    tmp = lineint(Line(stars[0], stars[1]), Line(stars[2], stars[3]));
    if (check(tmp)) {
        cout << "Yes" << endl << tmp.x << ' ' << tmp.y;
        return;
    }
    tmp = lineint(Line(stars[0], stars[2]), Line(stars[1], stars[3]));
    if (check(tmp)) {
        cout << "Yes" << endl << tmp.x << ' ' << tmp.y;
        return;
    }
    tmp = lineint(Line(stars[0], stars[3]), Line(stars[1], stars[2]));
    if (check(tmp)) {
        cout << "Yes" << endl << tmp.x << ' ' << tmp.y;
        return;
    }
    cout << "No";
    return;
}

int main() {

    //debuglineint();
    //debugsegint();
    //debugmirror();
    sol();
    return 0;
}