#include<cstdio>
#include<cstdlib>
#include<utility>
#include<set>
#include<map>
#include<iostream>
#include<vector>
#include<cmath>
#include<algorithm>
#include<iomanip>
#include<stack>


using namespace std;

const long double pi = 3.14159265358;
const long double inf = 1e15;

struct Point {
	long double x, y;

	Point(long double  x0 = 0, long double y0 = 0) {
		x = x0;
		y = y0;
	}

	long double dist(Point A) {
		return  sqrt((abs(x - A.x))*(abs(x - A.x)) + (abs(y - A.y))*(abs(y - A.y)));
	}
};

struct Vector {
	long double x, y;

	Vector(long double x0 = 0, long double y0 = 0) {
		x = x0;
		y = y0;
	}

	Vector(Point A, Point B) {
		x = B.x - A.x;
		y = B.y - A.y;
	}

	long double len() {
		return sqrtl(x*x + y * y);
	}

	long long size() {
		return (long long)x*x + (long long)y*y;
	}

	long double angle_ox() {
		long double phi = atan2(y, x);
		if (phi < 0) {
			phi += 2 * pi;
		}
		return phi;
	}

	long double angle(Vector B) {
		Vector A(x, y);
		long double proz1 = A.x * B.x + A.y*B.y;
		long double proz2 = A.x * B.y - A.y * B.x;

		long double phi = atan2(proz2, proz1);
		phi = abs(phi);
		return phi;
	}

};


Vector operator+(Vector a, Vector b) {
	return Vector(a.x + b.x, a.y + b.y);
}
bool operator<(Vector a, Vector b) {
	if (a.x == b.x) {
		return a.y < b.y;
	}
	return a.x < b.x;
}

Vector operator*(Vector a, long double k) {
	return Vector(a.x * k, a.y * k);
}

Vector operator*(long double k, Vector a) {
	return Vector(a.x * k, a.y * k);
}

Vector operator/(Vector a, long double l) {
	return Vector(a.x / l, a.y / l);
}

Vector operator-(Vector a, Vector b) {
	return Vector(a.x - b.x, a.y - b.y);
}

bool operator==(Vector a, Vector b) {
	return (a.x == b.x) && (a.y == b.y);
}

Point operator+(Point A, Vector AB) {
	return Point(A.x + AB.x, A.y + AB.y);
}

long double operator^(Vector A, Vector B) {
	return A.x * B.y - A.y * B.x;
}


long double operator&(Vector A, Vector B) {
	long double one = A.x * B.x;
	long double two = A.y * B.y;
	return A.x * B.x + A.y*B.y;

}

istream & operator>> (istream & in, Point & P) {
	in >> P.x >> P.y;
	return in;
}

ostream & operator<< (ostream & out, Point & P) {
	out << P.x << " " << P.y;
	return out;
}



struct line {
	long double a, b, c;

	line(Point A, Point B) {
		a = A.y - B.y;
		b = B.x - A.x;
		c = A.x * B.y - A.y * B.x;
	}

	line() {
		a = 0;
		b = 0;
		c = 0;
	}

	long double dist_to_line(Point P) {
		long double l = abs(a * P.x + b * P.y + c);
		return l / (hypot(a, b));
	}


	Point cord_min_dist(Point P) {
		Vector norm(a, b);

		norm = norm / norm.len();

		long double len = dist_to_line(P);

		norm = norm * len;

		Point ans1, ans2;

		ans1 = P + norm;

		norm = norm * -1;

		ans2 = P + norm;

		if (dist_to_line(ans1) < dist_to_line(ans2))
			return ans1;
		else
			return ans2;

	}

	Vector normal() {
		return Vector(a, b);
	}

	Vector sonoriginal() {
		return Vector(-b, a);
	}

	Point intersection(line A) {
		if (A.a == a && A.b == b) {
			return { -inf , -inf };
		}
		long double x = (A.b*c - b * A.c) / (A.a*b - a * A.b);
		long double y = (a*A.c - A.a*c) / (A.a*b - a * A.b);
		return { x,y };
	}


};

bool angle_have_point(Point A, Point O, Point B, Point P) {
	Vector OA(O, A);
	Vector OB(O, B);
	Vector OP(O, P);

	long double proiz1 = OA ^ OP;
	/*if (proiz1 == 0) {
	return false;
	}*/ // если точка на стороне угла - не пренадлежит
	long double proiz2 = OA ^ OB;

	long double proiz3 = OB ^ OP;
	long double proiz4 = OB ^ OA;
	if ((proiz1 * proiz2 >= 0) && (proiz3 * proiz4 >= 0))
		return true;

	else
		return false;

}


long long n;

Point q(Point a, Point b) {
	Point ans;
	ans.x = (a.x + b.x) / 2;
	ans.y = (a.y + b.y) / 2;
	return ans;
}
vector < Point > a;

Point start;

bool comp_convex_hull(Point a, Point b) {
	Vector a_start(a, start);
	Vector b_start(b, start);

	if ((a_start ^ b_start) == 0)
		return a.dist(start) < b.dist(start);

	return (a_start ^ b_start) > 0;
}

bool check(Point cent) {
	
	map < Vector, int > temp;
	set < Vector > used; 

	for (int i = 0; i < a.size(); i++) {
		Vector now(cent, a[i]);
		now = now / now.len();
		used.insert(now);
		temp[now]++;
	}

	for (auto elem : used) {
		Vector x = elem;
		Vector y = -1 * x;
		if (temp[x] + temp[y] != 0 && temp[x] + temp[y] != 2) {
			return false;
		}
	}

	return true;
}

int main() {
	
	cin >> n;
	a.assign(2 * n, { 0,0 });
	

	for (int i = 0; i < 2 * n; i++) {
		cin >> a[i];
	}





	for (int i = -1e3; i < 1e3; i++) {
		for (int j = -1e3; j < 1e3; j++) {
			Point moon(i, j);
			if (check(moon)) {
				cout << "Yes" << endl;
				cout << moon;
				system("pause");
				return 0;
			}
			
		}
	}
	cout << "No";
	system("pause");
	return 0;


}